



set ANACONDA_ANON_USAGE_DEBUG=1
IF %ERRORLEVEL% NEQ 0 exit /B 1
conda info
IF %ERRORLEVEL% NEQ 0 exit /B 1
python -m anaconda_anon_usage.install --status
IF %ERRORLEVEL% NEQ 0 exit /B 1
python tests/test_config.py
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
